@@ -271,14 +271,14 @@ class S3Client:
             for page in response_iterator:
                 logger.debug(page)
                 result.append(page)
-            if page is None or page['Marker'] == '':
+            if page is None or page.get('Marker') == '':
                 return page, result
             if size is not None:
                 if len(result) > size:
-                    return page['Marker'], result
+                    return page.get('Marker', ''), result
             try:
                 previous = marker
-                marker = page['Marker']
+                marker = page.get('Marker', '')
             except KeyError:
                 break
             if previous == marker and len(previous) > 0 and len(marker) > 0:
